set.seed(20180827)
n <- 1000
dataset <- data.frame(
  Area = runif(n, min = 1, max = 4),
  X = rnorm(n, mean = 2, sd = 1)
)
dataset$logArea <- log(dataset$Area)
dataset$eta <- 2 + 0.7 * dataset$X
dataset$lambda <- exp(dataset$eta) * dataset$Area
dataset$Y <- rpois(n, dataset$lambda)

# Model it with INLA. First using the defaults, then fixed the parameter of logArea to 1 by setting the prior to mean = 1 and var = 0.

library(INLA)
in1 = inla(
  Y ~ X + logArea,
  family = "poisson",
  data = dataset
)$summary.fixed
in2 = inla(
  Y ~ X + logArea,
  family = "poisson",
  control.fixed = list(
    mean = list(logArea = 1, default = 0),
    prec = list(logArea = 1e20, default = 0.001)
  ),
  data = dataset
)$summary.fixed

# bru() seems to ignore the options when passed as a list. Passing the output of bru.options() yields an error.

library(inlabru)
m <- bru(
  Y ~ X + logArea,
  family = "poisson",
  options = list(
    control.fixed = list(
      mean = list(logArea = 1, default = 0),
      prec = list(logArea = 1e20, default = 0.001)
    )
  ),
  data = dataset
)
br1 = m$summary.fixed
#summary(m)

m2 <- bru(
  Y ~ X(map = X, model = "linear", mean.linear = 0, prec.linear = 0.001) +
      logArea(map = logArea, model = "linear", mean.linear = 1, prec.linear = 1e20),
  family = "poisson",
  options = list(
    control.fixed = list(
      mean = list(logArea = 1, default = 0),
      prec = list(logArea = 1e20, default = 0.001)
    )
  ),
  data = dataset
)
br2 = m2$summary.fixed
#summary(m2)

message("No priors applied:")
print(in1)
message("bru ignores control.fixed:")
print(br1)

message("Priors are applied by inla and bru:")
print(in2)
print(br2)
